:
# NAME:
#	getndlog.sh - extract errors from named in a form useful to emacs
#
# SYNOPSIS:
#	getnderrs.sh "start_pid" ["messages"]
#	getndlog.sh "start_pid" ["messages"]
#
# DESCRIPTION:
#	Provides several functions for getting named log info.
#	If invoked as geterrs it produces output in the format of
#	'grep -n' so that emacs can visit the source of each error.
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: getndlog.sh,v 1.14 2008/01/26 04:38:38 sjg Exp $
#
#	@(#)Copyright (c) 1997-2001 Simon J. Gerraty.
#	All rights reserved.
#	
#	This software is the property of Simon J. Gerraty.
#	It may be used only in accordance with the conditions outlined
#	in the accompanying LICENSE file. If your distribution does
#	not contain a LICENSE file, then you have no rights to use
#	this software and should contact sales@crufty.net to obtain a
#	licensed distribution.
#	
#	This software is provided "AS IS" in the hope that it will be
#	of use.  Since it is not possible to anticipate all possible
#	use of this software, there is absolutely NO WARRANTY.
#
#	Please forward bug reports and fixes to help@crufty.net
#

RC_D=${RC_D:-/etc/rc_d}
$_SOURCE_SH . $RC_D/source.sh

_source getlog.sh $RC_D:$Mydir:$PATH

ndlog_def() {
	ND_STARTPID=${ND_STARTPID:-$1}
	MESSAGES=${MESSAGES:-$2}

	# this is from named_probs
	MESSAGES=${MESSAGES:-`getLog daemon`}
	# but just in case...
	MESSAGES=${MESSAGES:-/var/log/messages}
}

GetNamedLog() {
	ndlog_def "$@"
	case "$ND_PID" in
	"")	# don't know what it is yet
		sed -n "/\[$ND_STARTPID\]/,\$p" $MESSAGES | grep named
		;;
	*) 
		egrep "named.*\[($ND_STARTPID|$ND_PID)\]" $MESSAGES
		;;
	esac
}

GetNamedErrs() {
	GetNamedLog "$@" | sed 's,^.*\]: ,,' |
	egrep -i '(serial number interpreted|no such file|invalid|error|: (no|line|unknown)|illegal|warn|failed|found)' |
                egrep -v 'No default TTL|found.*CPU'
}

case $0 in
*get*errs*)	GetNamedErrs "$@";;
*get*log*)	GetNamedLog "$@";;
esac
